clear
clear matrix

*set location of base_directory below:
local base_dir "C:\DataAppendix_Dec2014\"

local in_dir "`base_dir'\data\raw"
local out_dir "`base_dir'\data"

*
* Format the NAFTA data
*

***uses windows command prompt to run operations on files!***


*append the csv files together and move out of the raw subfolder to main data folder
cd "`in_dir'\Bilateral_NAFTA"
!copy *.csv NAFTA.csv
!move NAFTA.csv "`out_dir'"
cd "`out_dir'"


insheet using "`out_dir'\NAFTA.csv", comma clear names

drop if year == "Year"

replace commoditycode = commoditycode + "0" if length(commoditycode) == 4

destring, replace


rename tradeflowcode flow

gen importer = reportercode if flow == 1
replace importer = partnercode if flow == 2

gen exporter = reportercode if flow == 2
replace exporter = partnercode if flow == 1


rename commoditycode code
gen quantity = netweightkg
replace quantity = supplementaryquantity if quantity == .

keep year importer exporter code value quantity quantityunitcode netweightkg


*label data
label var importer Importer
label var exporter Exporter
label var code "SITC Commodity Code"

label define country 124 "Canada" 484 "Mexico" 842 "UnitedStates" 0 "World"
label values importer country
label values exporter country

label define qcodes 1 "no quantity" 2 "area in square meters" 3 "electrical energy in thousands of kilowatts" 4 "meters" 5 "number of items" 6 "number of pairs" 7 "volume in liters" 8 "weight in kilograms" 9 "thousands of items" 10 "number of packages" 11 "dozen of items" 12 "volume in cubic meters" 13 "weight in carats"

label values quantityunitcode qcodes

keep year importer exporter code value quantity quantityunitcode netweightkg

order exporter importer code year value quantity quantityunitcode netweightkg


save "`out_dir'\NAFTA", replace

*delete the csv file
!del "`out_dir'\NAFTA.csv"