clear
clear matrix


*set location of base_directory below:
local base_dir "C:\DataAppendix_Dec2014\"

local in_dir "`base_dir'\data"
local out_dir "`base_dir'\output"
local temp_dir "`base_dir'\temp"


*
* Least Traded Exercise
*

use "`in_dir'\NAFTA", replace


gen pair = string(exporter,"%03.0f") + "-" + string(importer,"%03.0f") + "-" + string(code,"%05.0f")

drop quantity quantityunitcode netweightkg

fillin pair year
replace value=0 if value==.
replace exporter = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9]"))
replace importer = real(regexs(1)) if(regexm(pair,".([0-9][0-9][0-9])"))
replace code = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9][0-9][0-9]"))
drop _fillin

reshape wide value, i(pair) j(year)

gen pre_val = value1989

*right now I have the save post val for non-Can numbers
gen post_val = value2009

*drop the gas and elelectricity category goods and special transactions
drop if code == 34150
drop if code == 35100
drop if code == 93100


egen pre_val_avg = rowmean(value1989 value1990 value1991)

save "`temp_dir'\temp", replace

collapse (sum) pre_val, by(importer exporter)
rename pre_val pre_total

merge 1:m importer exporter using "`temp_dir'\temp"
drop _merge
save "`temp_dir'\temp", replace

sort importer exporter pre_val_avg

drop if pre_total==0
gen freq = pre_val/pre_total

by importer exporter, sort: gen cum_freq = sum(freq)

gen least=1 if cum_freq<0.10
replace least= (0.1-cum_freq[_n-1])*pre_total /pre_val if cum_freq >0.1 & cum_freq[_n-1]<0.1
replace least=0 if least==.


rename code sitc
recast int exporter importer

keep importer exporter pre_val post_val least sitc

save "`temp_dir'\temp", replace

*
*load industry tariff data
*
insheet using "`in_dir'\raw\NAFTAtariffs_product.csv", clear names

drop if product == "Product"
replace product = product + "0" if length(product) == 4

keep reporter partner product tariffyear simpleaverage

destring, replace

reshape wide simpleaverage, i(reporter* partner* product*) j(tariffyear)

rename simpleaverage1989 tariff_pre
rename simpleaverage2009 tariff_post

drop if reporter == partner
replace reporter = 842 if reporter == 840
replace partner = 842 if partner == 840

drop if reporter == 484

rename reporter importer
rename partner exporter
rename product sitc

merge 1:1 importer exporter sitc using "`temp_dir'\temp"
*drop if _merge == 1
drop _merge

save "`temp_dir'\temp", replace

*
*load industry tariff data for Mexico
*
insheet using "`in_dir'\raw\NAFTAtariffs_product_mex.csv", clear names

drop if product == "Product"
replace product = product + "0" if length(product) == 4

keep reporter partner product tariffyear simpleaverage

destring, replace

reshape wide simpleaverage, i(reporter* partner* product*) j(tariffyear)

rename simpleaverage1991 tariff_pre
rename simpleaverage2009 tariff_post

drop if reporter == partner
replace partner = 842 if partner == 840

rename reporter importer
rename partner exporter
rename product sitc

merge 1:1 importer exporter sitc using "`temp_dir'\temp"
*drop if _merge == 1
drop _merge

save "`temp_dir'\temp", replace


gen tariffchange = (1+tariff_post/100)-(1+tariff_pre/100)


save "`temp_dir'\temp", replace




*
* add in the GDP data
*


insheet using "`in_dir'\raw\GDP_input.txt", clear

rename canada GDP124
rename unitedstates GDP842
rename mexico GDP484
drop world

reshape long GDP, i(year) j(exporter)


reshape wide GDP, i(exporter) j(year)

keep exporter GDP1989 GDP2009



*
* merge with NAFTA Data
*

merge 1:m exporter using "`temp_dir'\temp"
drop _merge


gen GDP_pre = GDP1989
gen GDP_post = GDP2009


gen growth = 100*((post_val/GDP_post)/(pre_val/GDP_pre)-1)

label define ctry 124 "Can" 484 "Mex" 842 "USA"
label values importer ctry
label values exporter ctry

save "`out_dir'\NAFTA_Tariff_product", replace

use "`out_dir'\NAFTA_Tariff_product", replace

**drop outlier of dry milk for Canadian exports to Mexico
drop if sitc == 2242 & exporter == 124 & importer == 484



use "`out_dir'\NAFTA_Tariff_product", replace

**drop outlier of dry milk for Canadian exports to Mexico
drop if sitc == 2242 & exporter == 124 & importer == 484

keep if least == 1 | least == 0
collapse (mean) tariff_pre tariff_post [aweight = pre_val], by(exporter importer least)

gen LTP = "_LTP" if least == 1
replace LTP = "_nonLTP" if least == 0
drop least

reshape wide tariff_pre tariff_post, i(exporter importer) j(LTP) string

format tariff* %9.2f
outsheet using "`out_dir'\tables\Table 3 Tariff Rates.txt", names replace
